@@ -7,8 +7,7 @@ Translate an options data structure into command line args
 import sys
 import inspect
 import argparse
-import functools
-import collections
+from typing import Any, Dict, List, Tuple
 
 DEFAULT = "c17b9912c892bf60e7933ed1c912df4bc768e9cb25d0e0a5d7e5bebbca1c3dec"
 
@@ -20,12 +19,14 @@ def _keys(opts):
     return sorted(opts, key=lambda k: (opts[k].get("display_priority", sys.maxsize), k))
 
 
-def gather(hub, raw, cli, parse_cli):
+def gather(
+    hub, raw: Dict[str, Any], cli: str, parse_cli: bool
+) -> Tuple[Dict[str, Any], Dict[str, Any]]:
     """
     Return the cli arguments as they are parsed
     """
     if not parse_cli:
-        return {}
+        return {}, {}
     raw_cli = hub.config.args.get_cli(raw, cli)
     hub.config.args.init_parser()
     hub.config.args.subparsers(raw, cli)
@@ -36,7 +37,7 @@ def gather(hub, raw, cli, parse_cli):
     return cli_args, raw_cli
 
 
-def clean_defaults(hub, cli_args):
+def clean_defaults(hub, cli_args: Dict[str, Any]) -> Dict[str, Any]:
     """
     If anyone did not pass in an argument then the key will match the
     bad default and needs to be removed
@@ -54,13 +55,14 @@ def init_parser(hub):
         hub.config.ARGS["parser"] = argparse.ArgumentParser()
 
 
-def get_cli(hub, raw, cli):
+def get_cli(hub, raw: Dict[str, Any], cli: str) -> Dict[str, Any]:
     """
     Gather the arguments that need to be parsed by the CLI
     """
     ret = {}
     main = raw.get(cli, {}).get("CLI_CONFIG")
     main_raw = raw.get(cli, {}).get("CONFIG")
+
     for key, data in main.items():
         ret[key] = {}
         hub.pop.dicts.update(ret[key], data)
@@ -68,7 +70,7 @@ def get_cli(hub, raw, cli):
             hub.pop.dicts.update(ret[key], main_raw[key])
         if "source" in data:
             src = raw.get(data["source"], {}).get("CONFIG", {}).get(key)
-            if src:
+            if src is not None:
                 hub.pop.dicts.update(ret[key], src)
         if "default" in ret[key]:
             ret[key]["default"] = DEFAULT
@@ -76,7 +78,7 @@ def get_cli(hub, raw, cli):
     return ret
 
 
-def subparsers(hub, raw, cli):
+def subparsers(hub, raw: Dict[str, Any], cli: str) -> bool:
     """
     Look over the data and extract and set up the subparsers for subcommands
     """
@@ -100,7 +102,7 @@ def subparsers(hub, raw, cli):
     return True
 
 
-def setup(hub, raw_cli):
+def setup(hub, raw_cli: Dict[str, Any]) -> Dict[str, Any]:
     """
     Take in a pre-defined dict and translate it to args
 
@@ -201,7 +203,12 @@ def setup(hub, raw_cli):
     return defaults
 
 
-def parse(hub, args=None, namespace=None, only_parse_known_arguments=False):
+def parse(
+    hub,
+    args: List[str] = None,
+    namespace: argparse.Namespace = None,
+    only_parse_known_arguments: bool = False,
+) -> Dict[str, Any]:
     """
     Parse the command line options
     """
@@ -215,7 +222,7 @@ def parse(hub, args=None, namespace=None, only_parse_known_arguments=False):
     return opts_dict
 
 
-def render(hub, cli_args, raw_cli):
+def render(hub, cli_args: Dict[str, Any], raw_cli: Dict[str, Any]) -> Dict[str, Any]:
     """
     For options specified as such, take the string passed into the cli and
     render it using the specified render flag
